@@ -1,7 +1,7 @@
 use crypto_market_type::MarketType;
 use crypto_msg_type::MessageType;
 
-use crypto_msg_parser::{FundingRateMsg, OrderBookMsg, TradeMsg};
+use crypto_msg_parser::{get_msg_type, FundingRateMsg, OrderBookMsg, TradeMsg};
 use float_cmp::approx_eq;
 
 pub fn check_trade_fields(
@@ -10,12 +10,20 @@ pub fn check_trade_fields(
     pair: String,
     symbol: String,
     trade: &TradeMsg,
+    raw_msg: &str,
 ) {
     assert_eq!(trade.exchange, exchange);
     assert_eq!(trade.market_type, market_type);
     assert_eq!(trade.pair, pair);
     assert_eq!(trade.symbol, symbol);
     assert_eq!(trade.msg_type, MessageType::Trade);
+    if [
+        "binance", "bitmex", "bybit", "deribit", "ftx", "huobi", "okex",
+    ]
+    .contains(&exchange)
+    {
+        assert_eq!(MessageType::Trade, get_msg_type(exchange, raw_msg));
+    }
     assert!(trade.price > 0.0);
     assert!(trade.quantity_base > 0.0);
     assert!(trade.quantity_quote > 0.0);
@@ -39,12 +47,20 @@ pub fn check_orderbook_fields(
     pair: String,
     symbol: String,
     orderbook: &OrderBookMsg,
+    raw_msg: &str,
 ) {
     assert_eq!(orderbook.exchange, exchange);
     assert_eq!(orderbook.market_type, market_type);
     assert_eq!(orderbook.pair, pair);
     assert_eq!(orderbook.symbol, symbol);
     assert_eq!(orderbook.msg_type, MessageType::L2Event);
+    if [
+        "binance", "bitmex", "bybit", "deribit", "ftx", "huobi", "okex",
+    ]
+    .contains(&exchange)
+    {
+        assert_eq!(MessageType::L2Event, get_msg_type(exchange, raw_msg));
+    }
     assert_eq!(orderbook.timestamp.to_string().len(), 13);
 
     for order in orderbook.asks.iter() {
